package com.xkrs.microservice.controller;

import com.xkrs.microservice.common.encapsulation.PromptMessageEnum;
import com.xkrs.microservice.model.entity.IrrigationSarRecordEntity;
import com.xkrs.microservice.model.entity.TeaGardenPlotEntity;
import com.xkrs.microservice.model.qo.TeaGardenPlotQo;
import com.xkrs.microservice.service.TeaGardenPlotService;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Locale;
import java.util.Optional;

import static com.xkrs.microservice.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * 茶园地块管理
 * @author tajochen
 */
@RestController
@RequestMapping("/api/tea-garden-plot")
public class TeaGardenPlotController {

    /**
     * 获取区域信息
     */
    Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private TeaGardenPlotService teaGardenPlotService;

    @RequestMapping(value="/get/all",method = RequestMethod.GET)
    @CrossOrigin
    public String getAllRecord() {
        Iterable<TeaGardenPlotEntity> list = teaGardenPlotService.getAllRecord();
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,list,locale);
    }

    @RequestMapping(value="/get/id",method = RequestMethod.GET)
    @CrossOrigin
    public String getById(@RequestParam("id") Integer id) {
        Optional<TeaGardenPlotEntity> res = teaGardenPlotService.getAllRecordById(id);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,res,locale);
    }

    @RequestMapping(value="/get/status",method = RequestMethod.GET)
    @CrossOrigin
    public String getByStatus(@RequestParam("status") Integer status) {
        Iterable<TeaGardenPlotEntity> res = teaGardenPlotService.getAllRecordByStatus(status);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,res,locale);
    }

    @RequestMapping(value="/update",method = RequestMethod.POST)
//    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_general_user','auth_administor')")
    @CrossOrigin
    public String dataUpdate(@RequestBody TeaGardenPlotQo teaGardenPlotQo) {
        teaGardenPlotService.update(teaGardenPlotQo);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

    @RequestMapping(value="/add",method = RequestMethod.POST)
//    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_general_user','auth_administor','auth_farm_user')")
    @CrossOrigin
    public String dataAdd(@RequestBody TeaGardenPlotQo teaGardenPlotQo) {
        // 监测地块编号是否存在
        TeaGardenPlotEntity teaGardenPlotEntity = teaGardenPlotService.getAllRecordByDkbh(teaGardenPlotQo.getDkbh());
        if(teaGardenPlotEntity!=null){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"地块编号已存在",locale);
        }
        teaGardenPlotService.add(teaGardenPlotQo);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

    @RequestMapping(value="/delete",method = RequestMethod.DELETE)
//    @PreAuthorize("hasAnyAuthority('auth_system_manager','auth_general_user','auth_administor','auth_farm_user')")
    @CrossOrigin
    public String dataDelete(@RequestParam("id") Integer id) {
        int res = teaGardenPlotService.delete(id);
        if(res == 1){
            return outputEncapsulationObject(PromptMessageEnum.PARAM_ILLEGAL,"参数错误",locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,"",locale);
    }

}
